pub struct InstantiateMsg {
pub owner_addr: Option<String>,
}Fields
owner_addr: Option<String>Owner address of the contract, CronCat DAO will be the owner since it deploys the factory Only owner can execute messages in this contract If no owner_addr is passed sender will be used as owner address