pub struct Config {
pub owner_addr: Addr,
pub nominated_owner_addr: Option<Addr>,
}Fields
owner_addr: AddrThe owner of the Factory, the DAO responsible for all changes & usage All Execute methods are restricted to this address, the CronCat DAO
nominated_owner_addr: Option<Addr>Default empty, nominated owners must accept the nomination for ownership transfer to be safely completed.